# -*- coding: utf-8 -*-
"""
    country.py

    :copyright: (c) 2014 by Openlabs Technologies & Consulting (P) Limited
    :license: BSD, see LICENSE for more details.
"""
from trytond.model import fields
from trytond.pool import PoolMeta

__all__ = ['Country']
__metaclass__ = PoolMeta


class Country:
    'Country'
    __name__ = 'country.country'

    sequence = fields.Integer("Sequence", required=True)

    @classmethod
    def __setup__(cls):
        super(Country, cls).__setup__()
        cls._order.insert(0, ('sequence', 'ASC'))
        cls._order.insert(1, ('name', 'ASC'))

    @staticmethod
    def default_sequence():
        return 300



# -*- coding: utf-8 -*-
"""
    tests/test_country.py

    :copyright: (C) 2014 by Openlabs Technologies & Consulting (P) Limited
    :license: BSD, see LICENSE for more details.
"""
import sys
import os
DIR = os.path.abspath(os.path.normpath(os.path.join(
    __file__, '..', '..', '..', '..', '..', 'trytond'
)))
if os.path.isdir(DIR):
    sys.path.insert(0, os.path.dirname(DIR))
import unittest

import trytond.tests.test_tryton
from trytond.tests.test_tryton import POOL, USER
from trytond.transaction import Transaction
from trytond.tests.test_tryton import DB_NAME, CONTEXT


class TestCountry(unittest.TestCase):
    '''
    Test Country
    '''

    def setUp(self):
        """
        Set up data used in the tests.
        this method is called before each test function execution.
        """
        trytond.tests.test_tryton.install_module('country_sequence')

    def test0005create_country_with_sequence(self):
        '''
        Test if country is created with sequence
        '''
        Country = POOL.get('country.country')

        with Transaction().start(DB_NAME, USER, context=CONTEXT):
            country, = Country.create([{
                'name': 'India',
                'code': 'IN'
            }])

            self.assertEqual(country.sequence, 300)

            country1, country2, country3 = Country.create([{
                'name': 'United States',
                'code': 'US',
                'sequence': 100
            }, {
                'name': 'Australia',
                'code': 'AU',
                'sequence': 400
            }, {
                'name': 'Canada',
                'code': 'CA',
                'sequence': 100
            }])

            self.assertEqual(country1.sequence, 100)

            countries = Country.search([])
            self.assertEqual(countries[0].code, 'CA')
            self.assertEqual(countries[1].code, 'US')


def suite():
    """
    Define suite
    """
    test_suite = trytond.tests.test_tryton.suite()
    test_suite.addTests(
        unittest.TestLoader().loadTestsFromTestCase(TestCountry)
    )
    return test_suite

if __name__ == '__main__':
    unittest.TextTestRunner(verbosity=2).run(suite())
